@@ -8,10 +8,10 @@
 #ifndef notepad_h
 #define notepad_h
 
-#include <kparts/readwritepart.h>
 #include <KPluginFactory>
+#include <kparts/readwritepart.h>
 
-class KAboutData;
+class KPluginMetaData;
 class QTextEdit;
 
 /**
@@ -23,15 +23,11 @@ class NotepadPart : public KParts::ReadWritePart
 {
     Q_OBJECT
 public:
-    NotepadPart(QWidget *parentWidget,
-                QObject *parent,
-                const QVariantList &args = QVariantList());
-    virtual ~NotepadPart();
+    NotepadPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &metaData, const QVariantList &args = QVariantList());
+    ~NotepadPart() override;
 
     void setReadWrite(bool rw) override;
 
-    static KAboutData *createAboutData();
-
 protected:
     bool openFile() override;
     bool saveFile() override;
@@ -43,5 +39,4 @@ protected:
     QTextEdit *m_edit;
 };
 
-
 #endif
