@@ -10,15 +10,14 @@
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KLocalizedString>
-#include <KPluginLoader>
 #include <KPluginFactory>
 #include <partloader.h>
 
-#include <QMimeDatabase>
 #include <QAction>
 #include <QApplication>
-#include <QFileDialog>
 #include <QFile>
+#include <QFileDialog>
+#include <QMimeDatabase>
 #include <QTest>
 
 PartViewer::PartViewer()
@@ -27,11 +26,11 @@ PartViewer::PartViewer()
 
     QAction *paOpen = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), QStringLiteral("&Open file"), this);
     actionCollection()->addAction(QStringLiteral("file_open"), paOpen);
-    connect(paOpen, SIGNAL(triggered()), this, SLOT(slotFileOpen()));
+    connect(paOpen, &QAction::triggered, this, &PartViewer::slotFileOpen);
 
     QAction *paQuit = new QAction(QIcon::fromTheme(QStringLiteral("application-exit")), QStringLiteral("&Quit"), this);
     actionCollection()->addAction(QStringLiteral("file_quit"), paQuit);
-    connect(paQuit, SIGNAL(triggered()), this, SLOT(close()));
+    connect(paQuit, &QAction::triggered, this, &PartViewer::close);
 
     m_part = nullptr;
 
@@ -61,8 +60,7 @@ void PartViewer::openUrl(const QUrl &url)
     QMimeDatabase db;
     const QString mimeType = db.mimeTypeForUrl(url).name();
     QString errorString;
-    m_part = KParts::PartLoader::createPartInstanceForMimeType<KParts::ReadOnlyPart>(mimeType,
-             this, this, &errorString);
+    m_part = KParts::PartLoader::createPartInstanceForMimeType<KParts::ReadOnlyPart>(mimeType, this, this, &errorString);
 
     if (m_part) {
         switchToPart(url);
@@ -77,7 +75,9 @@ void PartViewer::openUrl(const QUrl &url)
     const QVector<KPluginMetaData> plugins = KParts::PartLoader::partsForMimeType(mimeType);
     for (const KPluginMetaData &plugin : plugins) {
         QAction *action = new QAction(plugin.name(), this);
-        connect(action, &QAction::triggered, this, [=] { loadPlugin(plugin, url); });
+        connect(action, &QAction::triggered, this, [=] {
+            loadPlugin(plugin, url);
+        });
         m_openWithActions.append(action);
     }
     if (!m_openWithActions.isEmpty()) {
@@ -99,8 +99,9 @@ void PartViewer::slotFileOpen()
 void PartViewer::loadPlugin(const KPluginMetaData &md, const QUrl &url)
 {
     delete m_part;
-    KPluginLoader loader(md.fileName());
-    m_part = loader.factory()->create<KParts::ReadOnlyPart>(this, this);
+    auto factory = KPluginFactory::loadFactory(md).plugin;
+    Q_ASSERT(factory);
+    m_part = factory->create<KParts::ReadOnlyPart>(this, this, QVariantList());
     if (m_part) {
         switchToPart(url);
     }
@@ -121,4 +122,3 @@ int main(int argc, char **argv)
     shell->show();
     return app.exec();
 }
-
